==> azure_storage_blobs-0.1.0.crate: azure_storage_blobs-0.1.0/src/blob/requests/mod.rs <==
mod acquire_lease_builder;
mod append_block_builder;
mod break_lease_builder;
mod change_lease_builder;
mod clear_page_builder;
mod copy_blob_builder;
mod copy_blob_from_url_builder;
mod delete_blob_builder;
mod delete_blob_snapshot_builder;
mod delete_blob_version_builder;
mod get_blob_builder;
mod get_blob_metadata_builder;
mod get_blob_properties_builder;
mod get_block_list_builder;
mod put_append_blob_builder;
mod put_block_blob_builder;
mod put_block_builder;
mod put_block_list_builder;
mod put_page_blob_builder;
mod release_lease_builder;
mod renew_lease_builder;
mod set_blob_metadata_builder;
mod source_content_md5;
mod update_page_builder;
pub use self::acquire_lease_builder::AcquireLeaseBuilder;
pub use self::append_block_builder::AppendBlockBuilder;
pub use self::break_lease_builder::BreakLeaseBuilder;
pub use self::change_lease_builder::ChangeLeaseBuilder;
pub use self::clear_page_builder::ClearPageBuilder;
pub use self::delete_blob_builder::DeleteBlobBuilder;
pub use self::delete_blob_snapshot_builder::DeleteBlobSnapshotBuilder;
pub use self::delete_blob_version_builder::DeleteBlobVersionBuilder;
pub use self::get_blob_builder::GetBlobBuilder;
pub use self::get_blob_metadata_builder::GetBlobMetadataBuilder;
pub use self::get_blob_properties_builder::GetBlobPropertiesBuilder;
pub use self::get_block_list_builder::GetBlockListBuilder;
pub use self::put_append_blob_builder::PutAppendBlobBuilder;
pub use self::put_block_blob_builder::PutBlockBlobBuilder;
pub use self::put_block_builder::PutBlockBuilder;
pub use self::put_block_list_builder::PutBlockListBuilder;
pub use self::put_page_blob_builder::PutPageBlobBuilder;
pub use self::release_lease_builder::ReleaseLeaseBuilder;
pub use self::renew_lease_builder::RenewLeaseBuilder;
pub use self::set_blob_metadata_builder::SetBlobMetadataBuilder;
pub use self::update_page_builder::UpdatePageBuilder;
pub use copy_blob_builder::CopyBlobBuilder;
pub use copy_blob_from_url_builder::CopyBlobFromUrlBuilder;
pub use source_content_md5::SourceContentMD5;

==> azure_storage_blobs-0.2.0.crate: azure_storage_blobs-0.2.0/src/blob/requests/mod.rs <==
mod acquire_lease_builder;
mod append_block_builder;
mod break_lease_builder;
mod change_lease_builder;
mod clear_page_builder;
mod copy_blob_builder;
mod copy_blob_from_url_builder;
mod delete_blob_builder;
mod delete_blob_snapshot_builder;
mod delete_blob_version_builder;
mod get_blob_builder;
mod get_blob_metadata_builder;
mod get_blob_properties_builder;
mod get_block_list_builder;
mod get_page_ranges_builder;
mod put_append_blob_builder;
mod put_block_blob_builder;
mod put_block_builder;
mod put_block_list_builder;
mod put_page_blob_builder;
mod release_lease_builder;
mod renew_lease_builder;
mod set_blob_metadata_builder;
mod set_blob_tier_builder;
mod source_content_md5;
mod update_page_builder;
pub use self::acquire_lease_builder::AcquireLeaseBuilder;
pub use self::append_block_builder::AppendBlockBuilder;
pub use self::break_lease_builder::BreakLeaseBuilder;
pub use self::change_lease_builder::ChangeLeaseBuilder;
pub use self::clear_page_builder::ClearPageBuilder;
pub use self::delete_blob_builder::DeleteBlobBuilder;
pub use self::delete_blob_snapshot_builder::DeleteBlobSnapshotBuilder;
pub use self::delete_blob_version_builder::DeleteBlobVersionBuilder;
pub use self::get_blob_builder::GetBlobBuilder;
pub use self::get_blob_metadata_builder::GetBlobMetadataBuilder;
pub use self::get_blob_properties_builder::GetBlobPropertiesBuilder;
pub use self::get_block_list_builder::GetBlockListBuilder;
pub use self::get_page_ranges_builder::GetPageRangesBuilder;
pub use self::put_append_blob_builder::PutAppendBlobBuilder;
pub use self::put_block_blob_builder::PutBlockBlobBuilder;
pub use self::put_block_builder::PutBlockBuilder;
pub use self::put_block_list_builder::PutBlockListBuilder;
pub use self::put_page_blob_builder::PutPageBlobBuilder;
pub use self::release_lease_builder::ReleaseLeaseBuilder;
pub use self::renew_lease_builder::RenewLeaseBuilder;
pub use self::set_blob_metadata_builder::SetBlobMetadataBuilder;
pub use self::set_blob_tier_builder::SetBlobTierBuilder;
pub use self::update_page_builder::UpdatePageBuilder;
pub use copy_blob_builder::CopyBlobBuilder;
pub use copy_blob_from_url_builder::CopyBlobFromUrlBuilder;
pub use source_content_md5::SourceContentMD5;
